@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "kaomel" "1.0.0"
+(define-package "kaomel" "20250923.1958"
   "A snappy kaomoji picker."
   '((emacs "27.1"))
   :url "https://github.com/gicrisf/kaomel"
-  :commit "a1a596e3c907457ea1e773b499c49b96fb93038a"
-  :revdesc "a1a596e3c907"
+  :commit "9476f16a72e61f08f403cb4dbe860e39f1856c7a"
+  :revdesc "9476f16a72e6"
   :keywords '("convenience" "extensions" "faces" "tools")
   :authors '(("Giovanni Crisalfi" . "giovanni.crisalfi@protonmail.com"))
   :maintainers '(("Giovanni Crisalfi" . "giovanni.crisalfi@protonmail.com")))
